@@ -2,6 +2,6 @@
 # mlxtend Machine Learning Library Extensions
 # Submodules with scikit-learn utilities
 
-from .feature_sel import FeatureSelector
+from .feature_sel import ColumnSelector
 
 
